@@ -996,6 +996,10 @@ car_tab_assist_export_apply(GtkWidget* w, gpointer data)
    car = gtk_combo_box_get_active_text(GTK_COMBO_BOX(car_selector));
 
    units = returnEntryUnits(car);
+   /* If entry units not defined then use display units */
+   if (units == -1)
+      units = returnUnits();
+
    if (units == CAR_MPG_US_INDEX)
       units_str = "MPG";
 	else if (units == CAR_MPG_IMP_INDEX)
