@@ -51,6 +51,7 @@ static GtkTreeViewColumn *cost_column = NULL;
 static GtkTreeViewColumn *extra1_column = NULL;
 static GtkTreeViewColumn *extra2_column = NULL;
 static GtkWidget    *tree = NULL;
+static GtkWidget *sw;
 
 
 static void car_selector_clicked_cb(GtkWidget* w, gpointer data);
@@ -63,7 +64,6 @@ static void data_tree_selection_changed_cb(GtkTreeSelection *, gpointer);
 void data_tab_layout(GtkWidget *window)
 {
    GtkCellRenderer *renderer;
-   GtkWidget *sw;
    GtkWidget    *button;
    GtkTreeSelection  *select;
 
@@ -95,7 +95,6 @@ void data_tab_layout(GtkWidget *window)
    gtk_combo_box_append_text(GTK_COMBO_BOX(display_selector), DATA_DISPLAY_ALERTS_STR);
    gtk_combo_box_append_text(GTK_COMBO_BOX(display_selector), DATA_DISPLAY_ACTIVITY_STR);
    gtk_combo_box_append_text(GTK_COMBO_BOX(display_selector), DATA_DISPLAY_TRIPS_STR);
-   gtk_combo_box_set_active(GTK_COMBO_BOX(display_selector), 0);
 
    store = gtk_list_store_new (7, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
                                   G_TYPE_STRING, G_TYPE_STRING);
@@ -190,6 +189,8 @@ void data_tab_layout(GtkWidget *window)
 
    gtk_widget_set_size_request(sw, 690, 300);
    gtk_container_add(GTK_CONTAINER(sw), (GtkWidget *)tree);
+
+   gtk_combo_box_set_active(GTK_COMBO_BOX(display_selector), 0);
 }
 
 void
@@ -504,7 +505,7 @@ data_tab_sort_string(
    /* Display   DATA_DATE_ROW   DATA_ODO_ROW  DATA_FUEL_ROW    DATA_MPG_ROW     DATA_COST_ROW */
    /* Mileage   DATE            DOUBLE        DOUBLE           DOUBLE           DOUBLE   */
    /* Alerts    INT             DOUBLE        STRING           STRING           NONE     */
-   /* Activity  DATE            DOUBLE        STRING           STRING           NONE     */
+   /* Activity  DATE            DOUBLE        STRING           STRING           DOUBLE   */
    /* Trips     DATE            DOUBLE        DATE             INT              STRING   */
 
    int     disp;
@@ -533,6 +534,8 @@ data_tab_sort_string(
          mode = 3;
       else if ((int)user_data == DATA_ODO_ROW)
          mode = 0;
+      else if ((int)user_data == DATA_COST_ROW)
+         mode = 0;
       else
          mode = 1;
    }
@@ -661,3 +664,15 @@ data_tree_selection_changed_cb(
    }
 }
 
+void
+data_tab_fullscreen(int fullscreen)
+{
+   if (sw)
+   {
+      if (fullscreen == 0)
+         gtk_widget_set_size_request(sw, 690, 300);
+      else
+         gtk_widget_set_size_request(sw, 810, 370);
+   }
+}
+
