@@ -31,6 +31,7 @@
 
 #include "entry_tab.h"
 #include "common_tab.h"
+#include "graph_tab.h"
 #include "mileagefile.h"
 
 #define NUM_BUTTON_SIZE 45
@@ -47,7 +48,6 @@ static GtkWidget *label3;
 static int        car_inserted = FALSE;
 
 static void car_selector_clicked_cb(GtkWidget* w, gpointer data);
-static void entry_today_date_clicked_cb(GtkWidget* w, gpointer data);
 static void entry_key_press_clicked_cb(GtkWidget* w, gpointer data);
 static void entry_backspace_clicked_cb(GtkWidget* w, gpointer data);
 static void entry_process_clicked_cb(GtkWidget* w, gpointer data);
@@ -359,14 +359,8 @@ entry_key_press_clicked_cb(GtkWidget* w, gpointer data)
 {
    GtkWidget  *dialog;
 
-   if (cur_selected_text == date_text)
-      gtk_entry_append_text(GTK_ENTRY(date_text), data);
-   else if (cur_selected_text == odo_text)
-      gtk_entry_append_text(GTK_ENTRY(odo_text), data);
-   else if (cur_selected_text == gal_text)
-      gtk_entry_append_text(GTK_ENTRY(gal_text), data);
-   else if (cur_selected_text == cost_text)
-      gtk_entry_append_text(GTK_ENTRY(cost_text), data);
+   if (cur_selected_text != NULL)
+      gtk_entry_append_text(GTK_ENTRY(cur_selected_text), data);
    else
    {
       dialog = gtk_message_dialog_new (NULL,
@@ -501,6 +495,7 @@ entry_process_clicked_cb(GtkWidget* w, gpointer data)
       addMileEntry(car, total_str,
             gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(previous_but)));
       common_tab_updateDisplayTab(car);
+      graph_tab_load_data(car);
       free(car);
 
       /* Clear all text fields */
