@@ -707,6 +707,10 @@ graph_mileage_year(
    units = returnUnits();
    entry_units = returnEntryUnits(car);
 
+   /* IF entry_units is not defined then use display units */
+   if (entry_units == -1)
+      entry_units = units;
+
    iter = sort_list;
    while (iter != NULL)
    {
@@ -1090,6 +1094,10 @@ graph_get_max_mileage()
    units = returnUnits();
    entry_units = returnEntryUnits(car);
 
+   /* IF entry_units are not defined then use display units */
+   if (entry_units == -1)
+      entry_units = units;
+
    iter = sort_list;
    while (iter != NULL)
    {
